summaryrefslogtreecommitdiffstats
path: root/konqueror/konq_combo.cc
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:58:25 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:58:25 -0600
commit2c01fd64ddde84a6d78b632f7f3b7c3560dc288c (patch)
tree65f4f4370cf4269757d7fa4d0f4d15996a1bf68f /konqueror/konq_combo.cc
parent73c08b592db45af554b9f21029bc549d70f683ab (diff)
downloadtdebase-2c01fd64ddde84a6d78b632f7f3b7c3560dc288c.tar.gz
tdebase-2c01fd64ddde84a6d78b632f7f3b7c3560dc288c.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 73c08b592db45af554b9f21029bc549d70f683ab.
Diffstat (limited to 'konqueror/konq_combo.cc')
-rw-r--r--konqueror/konq_combo.cc40
1 files changed, 20 insertions, 20 deletions
diff --git a/konqueror/konq_combo.cc b/konqueror/konq_combo.cc
index d958400fd..3d1a1003f 100644
--- a/konqueror/konq_combo.cc
+++ b/konqueror/konq_combo.cc
@@ -99,7 +99,7 @@ KonqCombo::KonqCombo( TQWidget *parent, const char *name )
m_pageSecurity( KonqMainWindow::NotCrypted )
{
setInsertionPolicy( NoInsertion );
- setSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Fixed ));
+ tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Fixed ));
Q_ASSERT( s_config );
@@ -272,14 +272,14 @@ void KonqCombo::updateItem( const TQPixmap& pix, const TQString& t, int index, c
listBox()->changeItem( item, index );
/*
- setUpdatesEnabled( false );
- lineEdit()->setUpdatesEnabled( false );
+ tqsetUpdatesEnabled( false );
+ lineEdit()->tqsetUpdatesEnabled( false );
removeItem( index );
insertItem( pix, t, index );
- setUpdatesEnabled( true );
- lineEdit()->setUpdatesEnabled( true );
+ tqsetUpdatesEnabled( true );
+ lineEdit()->tqsetUpdatesEnabled( true );
update();
*/
}
@@ -301,13 +301,13 @@ void KonqCombo::updatePixmaps()
{
saveState();
- setUpdatesEnabled( false );
+ tqsetUpdatesEnabled( false );
KonqPixmapProvider *prov = KonqPixmapProvider::self();
for ( int i = 1; i < count(); i++ ) {
updateItem( prov->pixmapFor( text( i ) ), text( i ), i, titleOfURL( text( i ) ) );
}
- setUpdatesEnabled( true );
- repaint();
+ tqsetUpdatesEnabled( true );
+ tqrepaint();
restoreState();
}
@@ -521,15 +521,15 @@ void KonqCombo::slotRemoved( const TQString& item )
void KonqCombo::removeURL( const TQString& url )
{
- setUpdatesEnabled( false );
- lineEdit()->setUpdatesEnabled( false );
+ tqsetUpdatesEnabled( false );
+ lineEdit()->tqsetUpdatesEnabled( false );
removeFromHistory( url );
applyPermanent();
setTemporary( currentText() );
- setUpdatesEnabled( true );
- lineEdit()->setUpdatesEnabled( true );
+ tqsetUpdatesEnabled( true );
+ lineEdit()->tqsetUpdatesEnabled( true );
update();
}
@@ -540,7 +540,7 @@ void KonqCombo::mousePressEvent( TQMouseEvent *e )
if ( e->button() == Qt::LeftButton && pixmap( currentItem()) ) {
// check if the pixmap was clicked
int x = e->pos().x();
- int x0 = TQStyle::visualRect( tqstyle().querySubControlMetrics( TQStyle::CC_ComboBox, this, TQStyle::SC_ComboBoxEditField ), this ).x();
+ int x0 = TQStyle::tqvisualRect( tqstyle().querySubControlMetrics( TQStyle::CC_ComboBox, this, TQStyle::SC_ComboBoxEditField ), this ).x();
if ( x > x0 + 2 && x < lineEdit()->x() ) {
m_dragStart = e->pos();
@@ -551,7 +551,7 @@ void KonqCombo::mousePressEvent( TQMouseEvent *e )
if ( e->button() == Qt::LeftButton && m_pageSecurity!=KonqMainWindow::NotCrypted ) {
// check if the lock icon was clicked
int x = e->pos().x();
- int x0 = TQStyle::visualRect( tqstyle().querySubControlMetrics( TQStyle::CC_ComboBox, this, TQStyle::SC_ComboBoxArrow ), this ).x();
+ int x0 = TQStyle::tqvisualRect( tqstyle().querySubControlMetrics( TQStyle::CC_ComboBox, this, TQStyle::SC_ComboBoxArrow ), this ).x();
if ( x < x0 )
emit showPageSecurity();
@@ -605,7 +605,7 @@ void KonqCombo::paintEvent( TQPaintEvent *pe )
TQLineEdit *edit = lineEdit();
TQRect re = tqstyle().querySubControlMetrics( TQStyle::CC_ComboBox, this, TQStyle::SC_ComboBoxEditField );
- re = TQStyle::visualRect(re, this);
+ re = TQStyle::tqvisualRect(re, this);
if ( m_pageSecurity!=KonqMainWindow::NotCrypted ) {
TQColor color(245, 246, 190);
@@ -646,7 +646,7 @@ void KonqCombo::paintEvent( TQPaintEvent *pe )
void KonqCombo::setPageSecurity( int pageSecurity )
{
m_pageSecurity = pageSecurity;
- repaint();
+ tqrepaint();
}
bool KonqCombo::hasSufficientContrast(const TQColor &c1, const TQColor &c2)
@@ -723,8 +723,8 @@ void KonqComboListBoxPixmap::paint( TQPainter *painter )
pmWidth = pm->width() + 5;
}
- int entryWidth = listBox()->width() - listBox()->tqstyle().pixelMetric( TQStyle::PM_ScrollBarExtent ) -
- 2 * listBox()->tqstyle().pixelMetric( TQStyle::PM_DefaultFrameWidth );
+ int entryWidth = listBox()->width() - listBox()->tqstyle().tqpixelMetric( TQStyle::PM_ScrollBarExtent ) -
+ 2 * listBox()->tqstyle().tqpixelMetric( TQStyle::PM_DefaultFrameWidth );
int titleWidth = ( entryWidth / 3 ) - 1;
int urlWidth = entryWidth - titleWidth - pmWidth - 2;
@@ -850,7 +850,7 @@ void KonqComboCompletionBox::setItems( const TQStringList& items )
insertStringList( items );
else {
//Keep track of whether we need to change anything,
//so we can avoid a repaint for identical updates,
//to reduce flicker
bool dirty = false;
@@ -884,7 +884,7 @@ void KonqComboCompletionBox::setItems( const TQStringList& items )
triggerUpdate( false );
}
- if ( isVisible() && size().height() != sizeHint().height() )
+ if ( isVisible() && size().height() != tqsizeHint().height() )
sizeAndPosition();
blockSignals( block );
@@ -850,7 +850,7 @@ void KonqComboCompletionBox::setItems( const TQStringList& items )
else {
//Keep track of whether we need to change anything,
- //so we can avoid a repaint for identical updates,
+ //so we can avoid a tqrepaint for identical updates,
//to reduce flicker
bool dirty = false;